
#include <sysqueue.h>
#include <linux/types.h>
#define u8 __u8

#define TimeZoneOffset timezone
